<?php

/**
 * @file
 * Theme settings for the Zentropy
 */
function zentropy_form_system_theme_settings_alter(&$form, &$form_state) {

  /**
   * Vertical tabs layout borrowed from Sasson
   * @link http://drupal.org/project/sasson 
   */
  drupal_add_css(drupal_get_path('theme', 'zentropy') .'/css/theme-settings.css');
  
  $form['zentropy_settings'] = array(
    '#type' => 'vertical_tabs',
    '#weight' => -10,
  );
  
  /**
   * General settings
   */
  $form['zentropy_settings']['zentropy_general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Settings'),
  );
  
  $form['zentropy_settings']['zentropy_general']['theme_settings'] = $form['theme_settings'];
  $form['zentropy_settings']['zentropy_general']['logo'] = $form['logo'];
  $form['zentropy_settings']['zentropy_general']['favicon'] = $form['favicon'];
  unset($form['theme_settings']);
  unset($form['logo']);
  unset($form['favicon']);
  
  $form['zentropy_settings']['zentropy_general']['zentropy_rss'] = array(
    '#type' => 'fieldset',
    '#title' => t('RSS'),
  );
  
  $form['zentropy_settings']['zentropy_general']['zentropy_rss']['zentropy_feed_icons'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display Feed Icons'),
    '#description' => t('Check this option to enable feed icons.'),
    '#default_value' => theme_get_setting('zentropy_feed_icons'),
  );
  
  /**
   * Development Settings 
   */
  $form['zentropy_settings']['zentropy_dev'] = array(
    '#type' => 'fieldset',
    '#title' => t('Development Settings'),
  );
  
  $form['zentropy_settings']['zentropy_dev']['zentropy_clear_registry'] = array(
    '#type' => 'checkbox',
    '#title' => t('Rebuild theme registry on every page.'),
    '#description' => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    '#default_value' => theme_get_setting('zentropy_clear_registry'),
  );
  
  $form['zentropy_settings']['zentropy_dev']['zentropy_wireframe_mode'] = array(
    '#type' => 'checkbox',
    '#title' =>  t('Wireframe Mode - Display borders around main layout elements'),
    '#description'   => t('<a href="!link">Wireframes</a> are useful when prototyping a website.', array('!link' => 'http://www.boxesandarrows.com/view/html_wireframes_and_prototypes_all_gain_and_no_pain')),
    '#default_value' => theme_get_setting('zentropy_wireframe_mode'),
  );
  
  /**
   * HTML5 Settings 
   */
  $form['zentropy_settings']['zentropy_html5'] = array(
    '#type' => 'fieldset',
    '#title' => t('HTML5 Support'),
  );
  
  $form['zentropy_settings']['zentropy_html5']['zentropy_shiv_google'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Google Code-Hosted HTML5Shiv'),
    '#description' => t('An HTML5Shiv is used to enable HTML5 elements in Internet Explorer 6, 7 and 8. Check this option to load the shiv from Google Code instead of locally.'),
    '#default_value' => theme_get_setting('zentropy_shiv_google'),
  );

  $form['zentropy_settings']['zentropy_html5']['zentropy_prompt_cf'] = array(
    '#type' => 'select', 
    '#title' => t('Prompt IE users to install Chrome Frame'),
    '#default_value' => theme_get_setting('zentropy_prompt_cf'),
    '#options' => drupal_map_assoc(array(
       'Disabled', 
       'IE 6', 
       'IE 7', 
       'IE 8', 
       'IE 9', 
    )),
      '#description' => t('Set the latest IE version you would like the prompt box to show on or disable if you want to support old IEs.'),
  );
  
  /**
   * Tab settings
   */
  $form['zentropy_settings']['zentropy_tabs'] = array(
    '#type' => 'fieldset',
    '#title' => t('Tab Settings'),
  );

  $form['zentropy_settings']['zentropy_tabs']['zentropy_zen_tabs'] = array(
    '#type' => 'checkbox',
    '#title' =>  t('Use the ZEN tabs'),
    '#description'   => t('Check this if you wish to replace the default tabs by the ZEN tabs.'),
    '#default_value' => theme_get_setting('zentropy_zen_tabs'),
    '#states' => array(
      'disabled' => array(
        'input[name="zentropy_tabs_float"]' => array('checked' => TRUE),
      ),
    ),
  );
  
  $form['zentropy_settings']['zentropy_tabs']['zentropy_tabs_float'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable floating tabs'),
    '#description' => t('Floating tabs appear attached to the left-side of the page and are less intrusive than regular tabs.'),
    '#default_value' => theme_get_setting('zentropy_tabs_float'),
    '#states' => array(
      'disabled' => array(
        'input[name="zentropy_zen_tabs"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['zentropy_settings']['zentropy_tabs']['zentropy_tabs_node'] = array(
    '#type' => 'checkbox',
    '#title' => t('Only for nodes'),
    '#description' => t('Check this option to only enable floating tabs for node pages.'),
    '#default_value' => theme_get_setting('zentropy_tabs_node'),
    '#states' => array(
      'visible' => array(
        'input[name="zentropy_tabs_float"]' => array('checked' => TRUE),
      ),
    ),
  );

  /**
   * Breadcrumb settings
   */
  $form['zentropy_settings']['zentropy_breadcrumb'] = array(
    '#type' => 'fieldset',
    '#title' => t('Breadcrumb Settings'),
  );

  $form['zentropy_settings']['zentropy_breadcrumb']['zentropy_breadcrumb_hideonlyfront'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide the breadcrumb if the breadcrumb only contains the link to the front page.'),
    '#default_value' => theme_get_setting('zentropy_breadcrumb_hideonlyfront'),
  );

  $form['zentropy_settings']['zentropy_breadcrumb']['zentropy_breadcrumb_showtitle'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show page title on breadcrumb.'),
    '#description' => t("Check this option to add the current page's title to the breadcrumb trail."),
    '#default_value' => theme_get_setting('zentropy_breadcrumb_showtitle'),
  );

  $form['zentropy_settings']['zentropy_breadcrumb']['zentropy_breadcrumb_separator'] = array(
    '#type' => 'textfield',
    '#title' => t('Breadcrumb separator'),
    '#default_value' => theme_get_setting('zentropy_breadcrumb_separator'),
    '#size' => 3,
  );
}