<?php

/**
 * @file
 * Drush commands for Zentropy.
 * 
 * Borrowed from zentropy
 * @link http://drupal.org/project/zentropy
 */

/**
 * Implements of hook_drush_command().
 */
function zentropy_drush_command() {
  return array(
    'zentropy-new-subtheme' => array(
      'description' => 'Set up a new Zentropy base theme.',
      'aliases' => array('zns'),
      'arguments' => array(
        'name' => 'A name for your theme.',
        'machine_name' => '(optional)[a-z, 0-9] A machine-readable name for your theme.',
      ),
      'examples' => array(
        'example[1]' => 'drush zns "My theme name"',
        'example[2]' => 'drush zns "My theme name" "my_theme_alias"',
      ),
    ),
  );
}

/**
 * Implements hook_drush_help().
 */
function zentropy_drush_help($section) {
  switch ($section) {
    case 'drush:zentropy-new-subtheme':
      return dt("Set up a new Zentropy base theme.");
  }
}

/**
 * Drush Command: Set up a Zentropy base theme.
 * 
 * @see zentropy_drush_command().
 */
function drush_zentropy_new_subtheme($name = NULL, $machine_name = NULL) {
  if (empty($name)) {
    drush_print(dt("\nWe can't create a subtheme with no name. \nPlease provide a name for the subtheme.\nEx. drush zns [name]\n"));
    return;
  }
  
  $machine_name = !empty($machine_name) ? preg_replace('/[^a-z0-9_]+/', '', strtolower($machine_name)) : preg_replace('/[^a-z0-9_]+/', '', strtolower($name));
  $zentropy_path = drush_locate_root() . '/' . drupal_get_path('theme', 'zentropy');

  // From Zentropy's location, we move up one directory and construct the path where our sub theme will be created.
  $_zentropy_path = explode('/', $zentropy_path);
  array_pop($_zentropy_path);
  $theme_dir = implode('/', $_zentropy_path);
  $subtheme_path = $theme_dir . '/' . $machine_name;

  // Make a fresh copy of the original starter kit.
  $s = drush_copy_dir("$zentropy_path/SUBTHEME/", $subtheme_path);
  if (empty($s)) {
    return;
  }

  // Rename the info file and fill in the theme name.
  drush_op('rename', "$subtheme_path/SUBTHEME.info", "$subtheme_path/$machine_name.info");
  drush_op('zentropy_file_str_replace', "$subtheme_path/$machine_name.info", 'SUBTHEME', "$machine_name");
  drush_op('zentropy_file_str_replace', "$subtheme_path/$machine_name.info", 'Zentropy Base Theme', "$name");

  // Rename default stylesheet and script files and fill in the theme name
  drush_op('rename', "$subtheme_path/css/SUBTHEME.css", "$subtheme_path/css/$machine_name.css");
  drush_op('rename', "$subtheme_path/js/SUBTHEME.js", "$subtheme_path/js/$machine_name.js");
  drush_op('zentropy_file_str_replace', "$subtheme_path/js/$machine_name.js", 'SUBTHEME', "$machine_name");
  
  // Rename screenshot
  drush_op('rename', "$subtheme_path/SUBTHEME.jpg", "$subtheme_path/$machine_name.jpg");
  
  // Fill in theme name in template.php
  drush_op('zentropy_file_str_replace', "$subtheme_path/template.php", 'Zentropy Base Theme', "$name");
  
  // Notify user of the newly created theme.
  drush_print(dt("\n!name sub-theme was created in !path. \n",
    array(
      '!name' => $name,
      '!path' => $subtheme_path,
    )
  ));
}

/**
 * Internal helper: Replace strings in a file.
 */
function zentropy_file_str_replace($file_path, $find, $replace) {
  $file_contents = file_get_contents($file_path);
  $file_contents = str_replace($find, $replace, $file_contents);
  file_put_contents($file_path, $file_contents);
}